@@ -3,27 +3,32 @@ function sun_j2sdk_doc_detect() {
   local found=
       case "$archive_name" in
 	"j2sdk-1_3_1-doc.zip") # SUPPORTED
-	    j2se_version=1.3.1
+	    j2se_version=1.3.1${revision}
 	    j2se_expected_min_size=22 # 22049 kB
 	    found=true
 	    ;;
 	"j2sdk-1_4_2-doc.zip") # SUPPORTED
-	    j2se_version=1.4.2
+	    j2se_version=1.4.2${revision}
 	    j2se_expected_min_size=33 # 33592 kB
 	    found=true
 	    ;;
 	"j2sdk-1_4_2-doc-ja.zip") # SUPPORTED
-	    j2se_version=1.4.2
+	    j2se_version=1.4.2${revision}
 	    j2se_expected_min_size=87 # 89150 kB
 	    found=true
 	    ;;
 	"jdk-1_5_0-doc.zip") # SUPPORTED
-	    j2se_version=1.5.0
+	    j2se_version=1.5.0${revision}
 	    j2se_expected_min_size=46 # 46386 kB
 	    found=true
 	    ;;
 	"jdk-1_5_0-doc-ja.zip") # SUPPORTED
-	    j2se_version=1.5.0
+	    j2se_version=1.5.0${revision}
+	    j2se_expected_min_size=44 # 44566 kB
+	    found=true
+	    ;;
+	"jdk-6-doc.zip") # SUPPORTED
+	    j2se_version=1.6.0${revision}
 	    j2se_expected_min_size=44 # 44566 kB
 	    found=true
 	    ;;
