@@ -6,46 +6,61 @@ function sun_j2sdk_detect() {
     i386|i486-linux-gnu)
       case "$archive_name" in
 	"j2sdk-1_4_1_"[0-9][0-9]"-linux-i586.bin") # SUPPORTED
-	    j2se_version="1.4.1+${archive_name:12:2}"
+	    j2se_version="1.4.1+${archive_name:12:2}${revision}"
 	    j2se_expected_min_size=77 # 79515 kB
 	    found=true
 	    ;;
 	"j2sdk-1_4_2-linux-i586.bin") # SUPPORTED
-	    j2se_version=1.4.2
+	    j2se_version=1.4.2${revision}
 	    j2se_expected_min_size=87 # 89150 kB
 	    found=true
 	    ;;
 	"j2sdk-1_4_2_"[0-9][0-9]"-linux-i586.bin") # SUPPORTED
-	    j2se_version="1.4.2+${archive_name:12:2}"
+	    j2se_version="1.4.2+${archive_name:12:2}${revision}"
 	    j2se_expected_min_size=87 # 89281 kB
 	    found=true
 	    ;;
 	"jdk-1_5_0-beta2-linux-i586.bin") # SUPPORTED
-	    j2se_version=1.5.0+beta2
+	    j2se_version=1.5.0+beta2${revision}
 	    j2se_expected_min_size=122 # 125899 kB
 	    found=true
 	    ;;
 	"jdk-1_5_0-linux-i586.bin") # SUPPORTED
-	    j2se_version=1.5.0+update00
+	    j2se_version=1.5.0+update00${revision}
 	    j2se_expected_min_size=134 # 136608 kB
 	    found=true
 	    ;;
 	"jdk-1_5_0_"[0-9][0-9]"-linux-i586.bin") # SUPPORTED
-	    j2se_version=1.5.0+update${archive_name:10:2}
+	    j2se_version=1.5.0+update${archive_name:10:2}${revision}
+	    j2se_expected_min_size=130
+	    found=true
+	    ;;
+	"jdk-6-beta-linux-i586.bin") # SUPPORTED
+	    j2se_version=1.6.0+beta${revision}
+	    j2se_expected_min_size=130
+	    found=true
+	    ;;
+	"jdk-6-linux-i586.bin") # SUPPORTED
+	    j2se_version=1.6.0${revision}
+	    j2se_expected_min_size=130
+	    found=true
+	    ;;
+	"jdk-6u"[0-9]"-linux-i586.bin") # SUPPORTED
+	    j2se_version=1.6.0+update${archive_name:6:1}${revision}
 	    j2se_expected_min_size=130
 	    found=true
 	    ;;
       esac
       ;;
-    "ia64-linux")
+    ia64|ia64-linux-gnu)
       case "$archive_name" in
 	"j2sdk-1_4_1-linux-ia64.bin") # SUPPORTED
-	    j2se_version=1.4.1
+	    j2se_version=1.4.1${revision}
 	    j2se_expected_min_size=86 # 88452 kB
 	    found=true
 	    ;;
         "j2sdk-1_4_2_"[0-9][0-9]"-linux-ia64.bin") # SUPPORTED
-	    j2se_version="1.4.2+${archive_name:12:2}"
+	    j2se_version="1.4.2+${archive_name:12:2}${revision}"
 	    j2se_expected_min_size=107 # 109256 kB
 	    found=true
 	    ;;
@@ -54,20 +69,30 @@ function sun_j2sdk_detect() {
     amd64|x86_64-linux-gnu)
       case "$archive_name" in
 	"jdk-1_5_0-beta2-linux-amd64.bin") # SUPPORTED
-	    j2se_version=1.5.0+beta2
+	    j2se_version=1.5.0+beta2${revision}
 	    j2se_expected_min_size=108 # 110956 kB
 	    found=true
 	    ;;
 	"jdk-1_5_0-linux-amd64.bin") # SUPPORTED
-	    j2se_version=1.5.0+update00
+	    j2se_version=1.5.0+update00${revision}
 	    j2se_expected_min_size=110 # 112940 kB
 	    found=true
 	    ;;
 	"jdk-1_5_0_"[0-9][0-9]"-linux-amd64.bin") # SUPPORTED
-	    j2se_version=1.5.0+update${archive_name:10:2}
+	    j2se_version=1.5.0+update${archive_name:10:2}${revision}
 	    j2se_expected_min_size=105
 	    found=true
 	    ;;
+	"jdk-6-linux-amd64.bin") # SUPPORTED
+	    j2se_version=1.6.0${revision}
+	    j2se_expected_min_size=130
+	    found=true
+	    ;;
+	"jdk-6u"[0-9]"-linux-amd64.bin") # SUPPORTED
+	    j2se_version=1.6.0+update${archive_name6:1}${revision}
+	    j2se_expected_min_size=130
+	    found=true
+	    ;;
       esac
       ;;
   esac
